@@ -18,7 +18,7 @@ package Dist::Zilla::Plugin::TemplateCJM;
 #---------------------------------------------------------------------
 
 our $VERSION = '3.00';
-# This file is part of Dist-Zilla-Plugins-CJM 3.01 (August 9, 2010)
+# This file is part of Dist-Zilla-Plugins-CJM 3.02 (November 11, 2010)
 
 
 use Moose;
@@ -367,8 +367,8 @@ Dist::Zilla::Plugin::TemplateCJM - Process templates, including version numbers
 =head1 VERSION
 
 This document describes version 3.00 of
-Dist::Zilla::Plugin::TemplateCJM, released August 9, 2010
-as part of Dist-Zilla-Plugins-CJM version 3.01.
+Dist::Zilla::Plugin::TemplateCJM, released November 11, 2010
+as part of Dist-Zilla-Plugins-CJM version 3.02.
 
 =head1 SYNOPSIS
 
@@ -601,7 +601,7 @@ or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM>
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
-L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
+git://github.com/madsen/dist-zilla-plugins-cjm.git.
 
 =head1 COPYRIGHT AND LICENSE
 
